@@ -146,42 +146,6 @@ Output::GlobalConfig Output::readGlobal(const KScreen::OutputPtr &output)
     return fromInfo(output, getGlobalData(output));
 }
 
-KScreen::Output::Rotation orientationToRotation(QOrientationReading::Orientation orientation, KScreen::Output::Rotation fallback)
-{
-    using Orientation = QOrientationReading::Orientation;
-
-    switch (orientation) {
-    case Orientation::TopUp:
-        return KScreen::Output::Rotation::None;
-    case Orientation::TopDown:
-        return KScreen::Output::Rotation::Inverted;
-    case Orientation::LeftUp:
-        return KScreen::Output::Rotation::Left;
-    case Orientation::RightUp:
-        return KScreen::Output::Rotation::Right;
-    case Orientation::Undefined:
-    case Orientation::FaceUp:
-    case Orientation::FaceDown:
-        return fallback;
-    default:
-        Q_UNREACHABLE();
-    }
-}
-
-bool Output::updateOrientation(KScreen::OutputPtr &output, QOrientationReading::Orientation orientation)
-{
-    if (output->type() != KScreen::Output::Type::Panel) {
-        return false;
-    }
-    const auto currentRotation = output->rotation();
-    const auto rotation = orientationToRotation(orientation, currentRotation);
-    if (rotation == currentRotation) {
-        return true;
-    }
-    output->setRotation(rotation);
-    return true;
-}
-
 // TODO: move this into the Layouter class.
 void Output::adjustPositions(KScreen::ConfigPtr config, const QVariantList &outputsInfo)
 {
